@@ -2,8 +2,8 @@ import io
 import os
 import shutil
 import stat
+import sys
 
-import six
 from crontab import CronTab
 from dagster import DagsterInstance, check, utils
 from dagster.core.host_representation import ExternalSchedule
@@ -19,7 +19,8 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
     """
 
     def __init__(
-        self, inst_data=None,
+        self,
+        inst_data=None,
     ):
         self._inst_data = inst_data
 
@@ -48,11 +49,11 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
     def start_schedule(self, instance, external_schedule):
         check.inst_param(instance, "instance", DagsterInstance)
         check.inst_param(external_schedule, "external_schedule", ExternalSchedule)
-        schedule_origin_id = external_schedule.get_origin_id()
+        schedule_origin_id = external_schedule.get_external_origin_id()
 
         # If the cron job already exists, remove it. This prevents duplicate entries.
         # Then, add a new cron job to the cron tab.
-        if self.running_schedule_count(instance, external_schedule.get_origin_id()) > 0:
+        if self.running_schedule_count(instance, external_schedule.get_external_origin_id()) > 0:
             self._end_cron_job(instance, schedule_origin_id)
 
         self._start_cron_job(instance, external_schedule)
@@ -142,7 +143,7 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
         return command
 
     def _start_cron_job(self, instance, external_schedule):
-        schedule_origin_id = external_schedule.get_origin_id()
+        schedule_origin_id = external_schedule.get_external_origin_id()
         script_file = self._write_bash_script_to_file(instance, external_schedule)
         command = self._get_command(script_file, instance, schedule_origin_id)
 
@@ -189,7 +190,7 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
 
     def _write_bash_script_to_file(self, instance, external_schedule):
         # Get path to store bash script
-        schedule_origin_id = external_schedule.get_origin_id()
+        schedule_origin_id = external_schedule.get_external_origin_id()
         script_file = self._get_bash_script_file_path(instance, schedule_origin_id)
 
         # Get path to store schedule attempt logs
@@ -197,7 +198,7 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
         schedule_log_file_name = "{}_{}.result".format("${RUN_DATE}", schedule_origin_id)
         schedule_log_file_path = os.path.join(logs_directory, schedule_log_file_name)
 
-        local_target = external_schedule.get_origin()
+        local_target = external_schedule.get_external_origin()
 
         # Environment information needed for execution
         dagster_home = os.getenv("DAGSTER_HOME")
@@ -212,7 +213,7 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
 
             {python_exe} -m dagster api launch_scheduled_execution --schedule_name {schedule_name} {repo_cli_args} "{result_file}"
         """.format(
-            python_exe=local_target.executable_path,
+            python_exe=sys.executable,
             schedule_name=external_schedule.name,
             repo_cli_args=local_target.get_repo_cli_args(),
             result_file=schedule_log_file_path,
@@ -226,7 +227,7 @@ class SystemCronScheduler(Scheduler, ConfigurableClass):
         )
 
         with io.open(script_file, "w", encoding="utf-8") as f:
-            f.write(six.text_type(script_contents))
+            f.write(script_contents)
 
         st = os.stat(script_file)
         os.chmod(script_file, st.st_mode | stat.S_IEXEC)
