@@ -3,20 +3,17 @@ import re
 import subprocess
 import sys
 from contextlib import contextmanager
+from tempfile import TemporaryDirectory
 
 import pytest
 import yaml
 from dagster import ScheduleDefinition
 from dagster.core.definitions import lambda_solid, pipeline, repository
-from dagster.core.host_representation import (
-    ManagedGrpcPythonEnvRepositoryLocationOrigin,
-    RepositoryLocation,
-    RepositoryLocationHandle,
-)
+from dagster.core.host_representation import ManagedGrpcPythonEnvRepositoryLocationOrigin
 from dagster.core.instance import DagsterInstance, InstanceType
 from dagster.core.launcher.sync_in_memory_run_launcher import SyncInMemoryRunLauncher
 from dagster.core.run_coordinator import DefaultRunCoordinator
-from dagster.core.scheduler import ScheduleState, ScheduleStatus
+from dagster.core.scheduler.job import JobState, JobStatus, JobType, ScheduleJobData
 from dagster.core.scheduler.scheduler import (
     DagsterScheduleDoesNotExist,
     DagsterScheduleReconciliationError,
@@ -30,11 +27,7 @@ from dagster.core.storage.runs import InMemoryRunStorage
 from dagster.core.storage.schedules import SqliteScheduleStorage
 from dagster.core.test_utils import environ
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
-from dagster.seven import (
-    TemporaryDirectory,
-    get_current_datetime_in_utc,
-    get_timestamp_from_utc_datetime,
-)
+from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 from dagster_cron import SystemCronScheduler
 from freezegun import freeze_time
 
@@ -88,13 +81,13 @@ schedules_dict = {
         name="no_config_pipeline_daily_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"storage": {"filesystem": None}},
+        run_config={"intermediate_storage": {"filesystem": None}},
     ),
     "no_config_pipeline_every_min_schedule": ScheduleDefinition(
         name="no_config_pipeline_every_min_schedule",
         cron_schedule="* * * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"storage": {"filesystem": None}},
+        run_config={"intermediate_storage": {"filesystem": None}},
     ),
     "default_config_pipeline_every_min_schedule": ScheduleDefinition(
         name="default_config_pipeline_every_min_schedule",
@@ -123,15 +116,15 @@ def test_repository():
 
 @contextmanager
 def get_test_external_repo():
-    with RepositoryLocationHandle.create_from_repository_location_origin(
-        ManagedGrpcPythonEnvRepositoryLocationOrigin(
-            loadable_target_origin=LoadableTargetOrigin(
-                executable_path=sys.executable, python_file=__file__, attribute="test_repository",
-            ),
-            location_name="test_location",
-        )
-    ) as handle:
-        yield RepositoryLocation.from_handle(handle).get_repository("test_repository")
+    with ManagedGrpcPythonEnvRepositoryLocationOrigin(
+        loadable_target_origin=LoadableTargetOrigin(
+            executable_path=sys.executable,
+            python_file=__file__,
+            attribute="test_repository",
+        ),
+        location_name="test_location",
+    ).create_handle() as handle:
+        yield handle.create_location().get_repository("test_repository")
 
 
 @contextmanager
@@ -170,7 +163,7 @@ def test_init(restore_cron_tab):  # pylint:disable=unused-argument,redefined-out
             # Check schedules are saved to disk
             assert "schedules" in os.listdir(tempdir)
 
-            assert instance.all_stored_schedule_state()
+            assert instance.all_stored_job_state(job_type=JobType.SCHEDULE)
 
 
 @freeze_time("2019-02-27")
@@ -185,21 +178,26 @@ def test_re_init(restore_cron_tab):  # pylint:disable=unused-argument,redefined-
                 external_repo.get_external_schedule("no_config_pipeline_every_min_schedule")
             )
 
-            assert schedule_state.start_timestamp == get_timestamp_from_utc_datetime(now)
+            assert (
+                schedule_state.job_specific_data.start_timestamp
+                == get_timestamp_from_utc_datetime(now)
+            )
 
             # Check schedules are saved to disk
             assert "schedules" in os.listdir(tempdir)
 
-            schedule_states = instance.all_stored_schedule_state()
+            schedule_states = instance.all_stored_job_state(job_type=JobType.SCHEDULE)
 
             for state in schedule_states:
+                assert state.job_specific_data.scheduler == "SystemCronScheduler"
                 if state.name == "no_config_pipeline_every_min_schedule":
                     assert state == schedule_state
 
 
 @pytest.mark.parametrize("do_initial_reconcile", [True, False])
 def test_start_and_stop_schedule(
-    restore_cron_tab, do_initial_reconcile,
+    restore_cron_tab,
+    do_initial_reconcile,
 ):  # pylint:disable=unused-argument,redefined-outer-name
     with TemporaryDirectory() as tempdir:
         instance = define_scheduler_instance(tempdir)
@@ -209,7 +207,7 @@ def test_start_and_stop_schedule(
                 instance.reconcile_scheduler_state(external_repo)
 
             schedule = external_repo.get_external_schedule("no_config_pipeline_every_min_schedule")
-            schedule_origin_id = schedule.get_origin_id()
+            schedule_origin_id = schedule.get_external_origin_id()
 
             instance.start_schedule_and_update_storage_state(schedule)
 
@@ -238,7 +236,8 @@ def test_start_non_existent_schedule(
 
 @pytest.mark.parametrize("do_initial_reconcile", [True, False])
 def test_start_schedule_cron_job(
-    do_initial_reconcile, restore_cron_tab,
+    do_initial_reconcile,
+    restore_cron_tab,
 ):  # pylint:disable=unused-argument,redefined-outer-name
     with TemporaryDirectory() as tempdir:
         instance = define_scheduler_instance(tempdir)
@@ -263,7 +262,7 @@ def test_start_schedule_cron_job(
             assert len(cron_jobs) == 3
 
             external_schedules_dict = {
-                external_repo.get_external_schedule(name).get_origin_id(): schedule_def
+                external_repo.get_external_schedule(name).get_external_origin_id(): schedule_def
                 for name, schedule_def in schedules_dict.items()
             }
 
@@ -294,11 +293,11 @@ def test_remove_schedule_def(
         with get_test_external_repo() as external_repo:
             instance.reconcile_scheduler_state(external_repo)
 
-            assert len(instance.all_stored_schedule_state()) == 3
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 3
             with get_smaller_external_repo() as smaller_repo:
                 instance.reconcile_scheduler_state(smaller_repo)
 
-            assert len(instance.all_stored_schedule_state()) == 2
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 2
 
 
 def test_add_schedule_def(restore_cron_tab):  # pylint:disable=unused-argument,redefined-outer-name
@@ -314,7 +313,7 @@ def test_add_schedule_def(restore_cron_tab):  # pylint:disable=unused-argument,r
                 external_repo.get_external_schedule("no_config_pipeline_every_min_schedule")
             )
 
-            assert len(instance.all_stored_schedule_state()) == 2
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 2
             assert len(get_cron_jobs()) == 2
             assert len(instance.scheduler_debug_info().errors) == 0
 
@@ -323,7 +322,7 @@ def test_add_schedule_def(restore_cron_tab):  # pylint:disable=unused-argument,r
             # Reconcile with an additional schedule added
             instance.reconcile_scheduler_state(external_repo)
 
-            assert len(instance.all_stored_schedule_state()) == 3
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 3
             assert len(get_cron_jobs()) == 2
             assert len(instance.scheduler_debug_info().errors) == 0
 
@@ -331,7 +330,7 @@ def test_add_schedule_def(restore_cron_tab):  # pylint:disable=unused-argument,r
                 external_repo.get_external_schedule("default_config_pipeline_every_min_schedule")
             )
 
-            assert len(instance.all_stored_schedule_state()) == 3
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 3
             assert len(get_cron_jobs()) == 3
             assert len(instance.scheduler_debug_info().errors) == 0
 
@@ -368,7 +367,7 @@ def test_start_and_stop_schedule_cron_tab(
             instance.stop_schedule_and_update_storage_state(
                 external_repo.get_external_schedule(
                     "no_config_pipeline_daily_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
             cron_jobs = get_cron_jobs()
             assert len(cron_jobs) == 1
@@ -377,7 +376,7 @@ def test_start_and_stop_schedule_cron_tab(
             instance.stop_schedule_and_update_storage_state(
                 external_repo.get_external_schedule(
                     "no_config_pipeline_daily_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
             cron_jobs = get_cron_jobs()
             assert len(cron_jobs) == 1
@@ -409,17 +408,17 @@ def test_start_and_stop_schedule_cron_tab(
             instance.stop_schedule_and_update_storage_state(
                 external_repo.get_external_schedule(
                     "no_config_pipeline_every_min_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
             instance.stop_schedule_and_update_storage_state(
                 external_repo.get_external_schedule(
                     "no_config_pipeline_daily_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
             instance.stop_schedule_and_update_storage_state(
                 external_repo.get_external_schedule(
                     "default_config_pipeline_every_min_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
 
             cron_jobs = get_cron_jobs()
@@ -457,9 +456,11 @@ def test_script_execution(
 
             schedule_origin_id = external_repo.get_external_schedule(
                 "no_config_pipeline_every_min_schedule"
-            ).get_origin_id()
-            script = instance.scheduler._get_bash_script_file_path(  # pylint: disable=protected-access
-                instance, schedule_origin_id
+            ).get_external_origin_id()
+            script = (
+                instance.scheduler._get_bash_script_file_path(  # pylint: disable=protected-access
+                    instance, schedule_origin_id
+                )
             )
 
             subprocess.check_output([script], shell=True, env={"DAGSTER_HOME": tempdir})
@@ -485,13 +486,13 @@ def test_start_schedule_fails(
                     external_repo.get_external_schedule("no_config_pipeline_every_min_schedule")
                 )
 
-            schedule = instance.get_stored_schedule_state(
+            schedule = instance.get_job_state(
                 external_repo.get_external_schedule(
                     "no_config_pipeline_every_min_schedule"
-                ).get_origin_id()
+                ).get_external_origin_id()
             )
 
-            assert schedule.status == ScheduleStatus.STOPPED
+            assert schedule.status == JobStatus.STOPPED
 
 
 def test_start_schedule_unsuccessful(
@@ -533,7 +534,7 @@ def test_start_schedule_manual_delete_debug(
                 instance,
                 external_repo.get_external_schedule(
                     "no_config_pipeline_every_min_schedule"
-                ).get_origin_id(),
+                ).get_external_origin_id(),
             )
 
             # Check debug command
@@ -587,10 +588,12 @@ def test_start_schedule_manual_duplicate_schedules_add_debug(
 
             # Manually add  extra cron tabs
             instance.scheduler._start_cron_job(  # pylint: disable=protected-access
-                instance, external_schedule,
+                instance,
+                external_schedule,
             )
             instance.scheduler._start_cron_job(  # pylint: disable=protected-access
-                instance, external_schedule,
+                instance,
+                external_schedule,
             )
 
             # Check debug command
@@ -613,7 +616,7 @@ def test_stop_schedule_fails(
             external_schedule = external_repo.get_external_schedule(
                 "no_config_pipeline_every_min_schedule"
             )
-            schedule_origin_id = external_schedule.get_origin_id()
+            schedule_origin_id = external_schedule.get_external_origin_id()
 
             def raises(*args, **kwargs):
                 raise Exception("Patch")
@@ -632,9 +635,9 @@ def test_stop_schedule_fails(
             with pytest.raises(Exception, match="Patch"):
                 instance.stop_schedule_and_update_storage_state(schedule_origin_id)
 
-            schedule = instance.get_stored_schedule_state(schedule_origin_id)
+            schedule = instance.get_job_state(schedule_origin_id)
 
-            assert schedule.status == ScheduleStatus.RUNNING
+            assert schedule.status == JobStatus.RUNNING
 
 
 def test_stop_schedule_unsuccessful(
@@ -663,7 +666,7 @@ def test_stop_schedule_unsuccessful(
                 instance.stop_schedule_and_update_storage_state(
                     external_repo.get_external_schedule(
                         "no_config_pipeline_every_min_schedule"
-                    ).get_origin_id()
+                    ).get_external_origin_id()
                 )
 
 
@@ -681,7 +684,7 @@ def test_wipe(restore_cron_tab):  # pylint:disable=unused-argument,redefined-out
             instance.wipe_all_schedules()
 
             # Check schedules are wiped
-            assert instance.all_stored_schedule_state() == []
+            assert instance.all_stored_job_state(job_type=JobType.SCHEDULE) == []
 
 
 def test_log_directory(restore_cron_tab):  # pylint:disable=unused-argument,redefined-outer-name
@@ -692,11 +695,13 @@ def test_log_directory(restore_cron_tab):  # pylint:disable=unused-argument,rede
             external_schedule = external_repo.get_external_schedule(
                 "no_config_pipeline_every_min_schedule"
             )
-            schedule_log_path = instance.logs_path_for_schedule(external_schedule.get_origin_id())
+            schedule_log_path = instance.logs_path_for_schedule(
+                external_schedule.get_external_origin_id()
+            )
 
             assert schedule_log_path.endswith(
                 "/schedules/logs/{schedule_origin_id}/scheduler.log".format(
-                    schedule_origin_id=external_schedule.get_origin_id()
+                    schedule_origin_id=external_schedule.get_external_origin_id()
                 )
             )
 
@@ -707,7 +712,7 @@ def test_log_directory(restore_cron_tab):  # pylint:disable=unused-argument,rede
             instance.wipe_all_schedules()
 
             # Check schedules are wiped
-            assert instance.all_stored_schedule_state() == []
+            assert instance.all_stored_job_state(job_type=JobType.SCHEDULE) == []
 
 
 def test_reconcile_failure(restore_cron_tab):  # pylint:disable=unused-argument,redefined-outer-name
@@ -747,24 +752,25 @@ def test_reconcile_schedule_without_start_time():
                 "no_config_pipeline_daily_schedule"
             )
 
-            legacy_schedule_state = ScheduleState(
-                external_schedule.get_origin(),
-                ScheduleStatus.RUNNING,
-                external_schedule.cron_schedule,
-                None,
+            legacy_schedule_state = JobState(
+                external_schedule.get_external_origin(),
+                JobType.SCHEDULE,
+                JobStatus.RUNNING,
+                ScheduleJobData(external_schedule.cron_schedule, None, "SystemCronScheduler"),
             )
 
-            instance.add_schedule_state(legacy_schedule_state)
+            instance.add_job_state(legacy_schedule_state)
 
             instance.reconcile_scheduler_state(external_repository=external_repo)
 
-            reconciled_schedule_state = instance.get_stored_schedule_state(
-                external_schedule.get_origin_id()
+            reconciled_schedule_state = instance.get_job_state(
+                external_schedule.get_external_origin_id()
             )
 
-            assert reconciled_schedule_state.status == ScheduleStatus.RUNNING
-            assert reconciled_schedule_state.start_timestamp == get_timestamp_from_utc_datetime(
-                get_current_datetime_in_utc()
+            assert reconciled_schedule_state.status == JobStatus.RUNNING
+            assert (
+                reconciled_schedule_state.job_specific_data.start_timestamp
+                == get_timestamp_from_utc_datetime(get_current_datetime_in_utc())
             )
 
 
@@ -777,7 +783,7 @@ def test_reconcile_failure_when_deleting_schedule_def(
 
             instance.reconcile_scheduler_state(external_repo)
 
-            assert len(instance.all_stored_schedule_state()) == 3
+            assert len(instance.all_stored_job_state(job_type=JobType.SCHEDULE)) == 3
 
             def failed_end_job(*_):
                 raise DagsterSchedulerError("Failed to stop")
@@ -787,7 +793,8 @@ def test_reconcile_failure_when_deleting_schedule_def(
             )
 
             with pytest.raises(
-                DagsterScheduleReconciliationError, match="Error 1: Failed to stop",
+                DagsterScheduleReconciliationError,
+                match="Error 1: Failed to stop",
             ):
                 with get_smaller_external_repo() as smaller_repo:
                     instance.reconcile_scheduler_state(smaller_repo)
